# taptogo
A python interface to the LA Metro TAP To Go site

## Install
Taptogo can be installed from pypi using pip :

```
pip install taptogo
```

## Tests
To run the test suite, export your TAP user and password and auto-run:

```
$ env TAPTOGO_EMAIL="<your-email>" TAPTOGO_PASSWORD="<your-password>" python -m unittest discover tests/
```
